@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "1.8.0";
+$Mojo::Webqq::VERSION = "1.8.1";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -217,6 +217,13 @@ sub new {
         $self->model_status->{$type} = $status;
         $self->emit("model_update_fail") if $self->get_model_status == 0;
     });
+    $self->on(before_send_message=>sub{
+        my($self,$msg) = @_;
+        my $content = $msg->content;
+        $content =~s/>/＞/g;
+        $content =~s/</＜/g;
+        $msg->content($content);
+    });
     $self->on(send_message=>sub{
         my($self,$msg,$status)=@_;
         if($status->is_success){$self->send_failure_count(0);}
