@@ -14,7 +14,8 @@ sub Mojo::Webqq::Client::_get_qrlogin_pic {
         v     => 4,
         t     => rand(),
     );  
-    my $data = $self->http_get($self->gen_url($api,@query_string),{Referer=>'https://ui.ptlogin2.qq.com/cgi-bin/login?daid=164&target=self&style=16&mibao_css=m_webqq&appid=501004106&enable_qlogin=0&no_verifyimg=1&s_url=http%3A%2F%2Fw.qq.com%2Fproxy.html&f_url=loginerroralert&strong_login=1&login_state=10&t=20131024001'});
+    my $url = $self->gen_url($api,@query_string);
+    my $data = $self->http_get($url,{Referer=>'https://ui.ptlogin2.qq.com/cgi-bin/login?daid=164&target=self&style=16&mibao_css=m_webqq&appid=501004106&enable_qlogin=0&no_verifyimg=1&s_url=http%3A%2F%2Fw.qq.com%2Fproxy.html&f_url=loginerroralert&strong_login=1&login_state=10&t=20131024001'});
     if( not defined $data){
         $self->error("登录二维码下载失败");
         return 0;
@@ -34,8 +35,8 @@ sub Mojo::Webqq::Client::_get_qrlogin_pic {
     }
 
     my $filename_for_log = encode("utf8",decode(locale_fs,$self->qrcode_path));
-    $self->info("二维码已下载到本地[ $filename_for_log ]");
-    $self->emit(input_qrcode=>$self->qrcode_path);
+    $self->info("二维码已下载到本地[ $filename_for_log ]\n二维码原始下载地址[ $url ]");
+    $self->emit(input_qrcode=>$self->qrcode_path,$url);
     return 1;
 }
 1;
